@@ -3,7 +3,17 @@
 set -e
 
 UPSTREAM_VERSION="$(dpkg-parsechangelog | sed -n '/^Version:/{s,^Version: ,,p}' | cut -d- -f1 | sed -e "s,\.dfsg,,")"
-UPSTREAM_TAG="dfsg/$(echo "${UPSTREAM_VERSION}" | tr '~' '_')"
+case "${UPSTREAM_VERSION}" in
+        *dfsg*)
+                UPSTREAM_TAG="dfsg/$(echo "${UPSTREAM_VERSION}" | tr '~' '_')"
+                ;;
+        *original*)
+                UPSTREAM_TAG="v$(echo "${UPSTREAM_VERSION}" | tr '~' '_' | sed -e 's,\.original,,')"
+                ;;
+        *)
+                UPSTREAM_TAG="v$(echo "${UPSTREAM_VERSION}" | tr '~' '_')"
+                ;;
+esac
 
 WD=$(pwd)
 TDIR=$(mktemp -d --tmpdir sng-upstream.XXXXXXXX)
@@ -19,6 +29,7 @@ echo "** Cloning..."
 
 git clone -q git://git.madhouse-project.org/debian/syslog-ng.git
 cd syslog-ng
+git checkout "${UPSTREAM_TAG}"
 git submodule --quiet update --init
 
 install -d debian/orig-source
@@ -52,7 +63,7 @@ git archive "${UPSTREAM_TAG}" --format tar --prefix=syslog-ng/ | \
 echo "** Creating the upstream tarball..."
 
 tar -C debian/orig-source -cf - syslog-ng | \
-	xz -9 >"${WD}"/syslog-ng_${UPSTREAM_VERSION}.dfsg.orig.tar.xz
+	xz -9 >"${WD}"/syslog-ng_${UPSTREAM_VERSION}.orig.tar.xz
 
 ##
 # Cleanup
@@ -62,4 +73,4 @@ echo "** Cleaning up."
 cd "${WD}"
 rm -rf "${TDIR}"
 
-echo "* Upstream tarball available in ${WD}/syslog-ng_${UPSTREAM_VERSION}.dfsg.orig.tar.xz"
+echo "* Upstream tarball available in ${WD}/syslog-ng_${UPSTREAM_VERSION}.orig.tar.xz"
